# coding: utf-8

# flake8: noqa
"""
    IONOS DBaaS MongoDB REST API

    With IONOS Cloud Database as a Service, you have the ability to quickly set up and manage a MongoDB database. You can also delete clusters, manage backups and users via the API.  MongoDB is an open source, cross-platform, document-oriented database program. Classified as a NoSQL database program, it uses JSON-like documents with optional schemas.  The MongoDB API allows you to create additional database clusters or modify existing ones. Both tools, the Data Center Designer (DCD) and the API use the same concepts consistently and are well suited for smooth and intuitive use.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from ionoscloud_dbaas_mongo.models.api_version import APIVersion
from ionoscloud_dbaas_mongo.models.cluster_list import ClusterList
from ionoscloud_dbaas_mongo.models.cluster_list_all_of import ClusterListAllOf
from ionoscloud_dbaas_mongo.models.cluster_logs import ClusterLogs
from ionoscloud_dbaas_mongo.models.cluster_logs_instances import ClusterLogsInstances
from ionoscloud_dbaas_mongo.models.cluster_logs_messages import ClusterLogsMessages
from ionoscloud_dbaas_mongo.models.cluster_properties import ClusterProperties
from ionoscloud_dbaas_mongo.models.cluster_response import ClusterResponse
from ionoscloud_dbaas_mongo.models.connection import Connection
from ionoscloud_dbaas_mongo.models.create_cluster_properties import CreateClusterProperties
from ionoscloud_dbaas_mongo.models.create_cluster_request import CreateClusterRequest
from ionoscloud_dbaas_mongo.models.create_restore_request import CreateRestoreRequest
from ionoscloud_dbaas_mongo.models.day_of_the_week import DayOfTheWeek
from ionoscloud_dbaas_mongo.models.error_message import ErrorMessage
from ionoscloud_dbaas_mongo.models.error_response import ErrorResponse
from ionoscloud_dbaas_mongo.models.health import Health
from ionoscloud_dbaas_mongo.models.maintenance_window import MaintenanceWindow
from ionoscloud_dbaas_mongo.models.metadata import Metadata
from ionoscloud_dbaas_mongo.models.pagination import Pagination
from ionoscloud_dbaas_mongo.models.pagination_links import PaginationLinks
from ionoscloud_dbaas_mongo.models.patch_cluster_properties import PatchClusterProperties
from ionoscloud_dbaas_mongo.models.patch_cluster_request import PatchClusterRequest
from ionoscloud_dbaas_mongo.models.patch_user_properties import PatchUserProperties
from ionoscloud_dbaas_mongo.models.patch_user_request import PatchUserRequest
from ionoscloud_dbaas_mongo.models.resource_type import ResourceType
from ionoscloud_dbaas_mongo.models.snapshot_list import SnapshotList
from ionoscloud_dbaas_mongo.models.snapshot_list_all_of import SnapshotListAllOf
from ionoscloud_dbaas_mongo.models.snapshot_properties import SnapshotProperties
from ionoscloud_dbaas_mongo.models.snapshot_response import SnapshotResponse
from ionoscloud_dbaas_mongo.models.state import State
from ionoscloud_dbaas_mongo.models.template_list import TemplateList
from ionoscloud_dbaas_mongo.models.template_list_all_of import TemplateListAllOf
from ionoscloud_dbaas_mongo.models.template_properties import TemplateProperties
from ionoscloud_dbaas_mongo.models.template_response import TemplateResponse
from ionoscloud_dbaas_mongo.models.user import User
from ionoscloud_dbaas_mongo.models.user_metadata import UserMetadata
from ionoscloud_dbaas_mongo.models.user_properties import UserProperties
from ionoscloud_dbaas_mongo.models.user_roles import UserRoles
from ionoscloud_dbaas_mongo.models.users_list import UsersList



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ionoscloud_dbaas_mongo.api.clusters_api import ClustersApi
from ionoscloud_dbaas_mongo.api.logs_api import LogsApi
from ionoscloud_dbaas_mongo.api.metadata_api import MetadataApi
from ionoscloud_dbaas_mongo.api.restores_api import RestoresApi
from ionoscloud_dbaas_mongo.api.snapshots_api import SnapshotsApi
from ionoscloud_dbaas_mongo.api.templates_api import TemplatesApi
from ionoscloud_dbaas_mongo.api.users_api import UsersApi



# coding: utf-8

"""
    IONOS DBaaS MongoDB REST API

    With IONOS Cloud Database as a Service, you have the ability to quickly set up and manage a MongoDB database. You can also delete clusters, manage backups and users via the API.  MongoDB is an open source, cross-platform, document-oriented database program. Classified as a NoSQL database program, it uses JSON-like documents with optional schemas.  The MongoDB API allows you to create additional database clusters or modify existing ones. Both tools, the Data Center Designer (DCD) and the API use the same concepts consistently and are well suited for smooth and intuitive use.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud_dbaas_mongo.configuration import Configuration


class CreateClusterProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'template_id': 'str',

        'mongo_db_version': 'str',

        'instances': 'int',

        'connections': 'list[Connection]',

        'location': 'str',

        'display_name': 'str',

        'maintenance_window': 'MaintenanceWindow',
    }

    attribute_map = {

        'template_id': 'templateID',

        'mongo_db_version': 'mongoDBVersion',

        'instances': 'instances',

        'connections': 'connections',

        'location': 'location',

        'display_name': 'displayName',

        'maintenance_window': 'maintenanceWindow',
    }

    def __init__(self, template_id=None, mongo_db_version=None, instances=None, connections=None, location=None, display_name=None, maintenance_window=None, local_vars_configuration=None):  # noqa: E501
        """CreateClusterProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._template_id = None
        self._mongo_db_version = None
        self._instances = None
        self._connections = None
        self._location = None
        self._display_name = None
        self._maintenance_window = None
        self.discriminator = None

        self.template_id = template_id
        if mongo_db_version is not None:
            self.mongo_db_version = mongo_db_version
        self.instances = instances
        self.connections = connections
        self.location = location
        self.display_name = display_name
        if maintenance_window is not None:
            self.maintenance_window = maintenance_window


    @property
    def template_id(self):
        """Gets the template_id of this CreateClusterProperties.  # noqa: E501

        The unique ID of the template, which specifies the number of cores, storage size, and memory. You cannot downgrade to a smaller template or minor edition (e.g. from business to playground). To get a list of all templates to confirm the changes use the /templates endpoint.   # noqa: E501

        :return: The template_id of this CreateClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this CreateClusterProperties.

        The unique ID of the template, which specifies the number of cores, storage size, and memory. You cannot downgrade to a smaller template or minor edition (e.g. from business to playground). To get a list of all templates to confirm the changes use the /templates endpoint.   # noqa: E501

        :param template_id: The template_id of this CreateClusterProperties.  # noqa: E501
        :type template_id: str
        """
        if self.local_vars_configuration.client_side_validation and template_id is None:  # noqa: E501
            raise ValueError("Invalid value for `template_id`, must not be `None`")  # noqa: E501

        self._template_id = template_id

    @property
    def mongo_db_version(self):
        """Gets the mongo_db_version of this CreateClusterProperties.  # noqa: E501

        The MongoDB version of your cluster.  # noqa: E501

        :return: The mongo_db_version of this CreateClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._mongo_db_version

    @mongo_db_version.setter
    def mongo_db_version(self, mongo_db_version):
        """Sets the mongo_db_version of this CreateClusterProperties.

        The MongoDB version of your cluster.  # noqa: E501

        :param mongo_db_version: The mongo_db_version of this CreateClusterProperties.  # noqa: E501
        :type mongo_db_version: str
        """

        self._mongo_db_version = mongo_db_version

    @property
    def instances(self):
        """Gets the instances of this CreateClusterProperties.  # noqa: E501

        The total number of instances in the cluster (one primary and n-1 secondaries).   # noqa: E501

        :return: The instances of this CreateClusterProperties.  # noqa: E501
        :rtype: int
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        """Sets the instances of this CreateClusterProperties.

        The total number of instances in the cluster (one primary and n-1 secondaries).   # noqa: E501

        :param instances: The instances of this CreateClusterProperties.  # noqa: E501
        :type instances: int
        """
        if self.local_vars_configuration.client_side_validation and instances is None:  # noqa: E501
            raise ValueError("Invalid value for `instances`, must not be `None`")  # noqa: E501

        self._instances = instances

    @property
    def connections(self):
        """Gets the connections of this CreateClusterProperties.  # noqa: E501


        :return: The connections of this CreateClusterProperties.  # noqa: E501
        :rtype: list[Connection]
        """
        return self._connections

    @connections.setter
    def connections(self, connections):
        """Sets the connections of this CreateClusterProperties.


        :param connections: The connections of this CreateClusterProperties.  # noqa: E501
        :type connections: list[Connection]
        """
        if self.local_vars_configuration.client_side_validation and connections is None:  # noqa: E501
            raise ValueError("Invalid value for `connections`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connections is not None and len(connections) > 1):
            raise ValueError("Invalid value for `connections`, number of items must be less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connections is not None and len(connections) < 1):
            raise ValueError("Invalid value for `connections`, number of items must be greater than or equal to `1`")  # noqa: E501

        self._connections = connections

    @property
    def location(self):
        """Gets the location of this CreateClusterProperties.  # noqa: E501

        The physical location where the cluster will be created. This is the location where all your instances will be located. This property is immutable.   # noqa: E501

        :return: The location of this CreateClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this CreateClusterProperties.

        The physical location where the cluster will be created. This is the location where all your instances will be located. This property is immutable.   # noqa: E501

        :param location: The location of this CreateClusterProperties.  # noqa: E501
        :type location: str
        """
        if self.local_vars_configuration.client_side_validation and location is None:  # noqa: E501
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def display_name(self):
        """Gets the display_name of this CreateClusterProperties.  # noqa: E501

        The name of your cluster.  # noqa: E501

        :return: The display_name of this CreateClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreateClusterProperties.

        The name of your cluster.  # noqa: E501

        :param display_name: The display_name of this CreateClusterProperties.  # noqa: E501
        :type display_name: str
        """
        if self.local_vars_configuration.client_side_validation and display_name is None:  # noqa: E501
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def maintenance_window(self):
        """Gets the maintenance_window of this CreateClusterProperties.  # noqa: E501


        :return: The maintenance_window of this CreateClusterProperties.  # noqa: E501
        :rtype: MaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """Sets the maintenance_window of this CreateClusterProperties.


        :param maintenance_window: The maintenance_window of this CreateClusterProperties.  # noqa: E501
        :type maintenance_window: MaintenanceWindow
        """

        self._maintenance_window = maintenance_window
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateClusterProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateClusterProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IONOS DBaaS MongoDB REST API

    With IONOS Cloud Database as a Service, you have the ability to quickly set up and manage a MongoDB database. You can also delete clusters, manage backups and users via the API.  MongoDB is an open source, cross-platform, document-oriented database program. Classified as a NoSQL database program, it uses JSON-like documents with optional schemas.  The MongoDB API allows you to create additional database clusters or modify existing ones. Both tools, the Data Center Designer (DCD) and the API use the same concepts consistently and are well suited for smooth and intuitive use.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud_dbaas_mongo.configuration import Configuration


class TemplateList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'type': 'ResourceType',

        'id': 'str',

        'items': 'list[TemplateResponse]',

        'offset': 'int',

        'limit': 'int',

        'links': 'PaginationLinks',
    }

    attribute_map = {

        'type': 'type',

        'id': 'id',

        'items': 'items',

        'offset': 'offset',

        'limit': 'limit',

        'links': 'links',
    }

    def __init__(self, type=None, id=None, items=None, offset=0, limit=100, links=None, local_vars_configuration=None):  # noqa: E501
        """TemplateList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._id = None
        self._items = None
        self._offset = None
        self._limit = None
        self._links = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if id is not None:
            self.id = id
        if items is not None:
            self.items = items
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if links is not None:
            self.links = links


    @property
    def type(self):
        """Gets the type of this TemplateList.  # noqa: E501


        :return: The type of this TemplateList.  # noqa: E501
        :rtype: ResourceType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TemplateList.


        :param type: The type of this TemplateList.  # noqa: E501
        :type type: ResourceType
        """

        self._type = type

    @property
    def id(self):
        """Gets the id of this TemplateList.  # noqa: E501

        The unique ID of the resource.  # noqa: E501

        :return: The id of this TemplateList.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TemplateList.

        The unique ID of the resource.  # noqa: E501

        :param id: The id of this TemplateList.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def items(self):
        """Gets the items of this TemplateList.  # noqa: E501


        :return: The items of this TemplateList.  # noqa: E501
        :rtype: list[TemplateResponse]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this TemplateList.


        :param items: The items of this TemplateList.  # noqa: E501
        :type items: list[TemplateResponse]
        """

        self._items = items

    @property
    def offset(self):
        """Gets the offset of this TemplateList.  # noqa: E501

        The offset specified in the request (if none was specified, the default offset is 0).   # noqa: E501

        :return: The offset of this TemplateList.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this TemplateList.

        The offset specified in the request (if none was specified, the default offset is 0).   # noqa: E501

        :param offset: The offset of this TemplateList.  # noqa: E501
        :type offset: int
        """
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset < 0):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `0`")  # noqa: E501

        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this TemplateList.  # noqa: E501

        The limit specified in the request (if none was specified, the default limit is 100).   # noqa: E501

        :return: The limit of this TemplateList.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this TemplateList.

        The limit specified in the request (if none was specified, the default limit is 100).   # noqa: E501

        :param limit: The limit of this TemplateList.  # noqa: E501
        :type limit: int
        """
        if (self.local_vars_configuration.client_side_validation and
                limit is not None and limit > 1000):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                limit is not None and limit < 0):  # noqa: E501
            raise ValueError("Invalid value for `limit`, must be a value greater than or equal to `0`")  # noqa: E501

        self._limit = limit

    @property
    def links(self):
        """Gets the links of this TemplateList.  # noqa: E501


        :return: The links of this TemplateList.  # noqa: E501
        :rtype: PaginationLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this TemplateList.


        :param links: The links of this TemplateList.  # noqa: E501
        :type links: PaginationLinks
        """

        self._links = links
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TemplateList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TemplateList):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IONOS DBaaS MongoDB REST API

    With IONOS Cloud Database as a Service, you have the ability to quickly set up and manage a MongoDB database. You can also delete clusters, manage backups and users via the API.  MongoDB is an open source, cross-platform, document-oriented database program. Classified as a NoSQL database program, it uses JSON-like documents with optional schemas.  The MongoDB API allows you to create additional database clusters or modify existing ones. Both tools, the Data Center Designer (DCD) and the API use the same concepts consistently and are well suited for smooth and intuitive use.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud_dbaas_mongo.configuration import Configuration


class CreateRestoreRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'snapshot_id': 'str',
    }

    attribute_map = {

        'snapshot_id': 'snapshotId',
    }

    def __init__(self, snapshot_id=None, local_vars_configuration=None):  # noqa: E501
        """CreateRestoreRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._snapshot_id = None
        self.discriminator = None

        self.snapshot_id = snapshot_id


    @property
    def snapshot_id(self):
        """Gets the snapshot_id of this CreateRestoreRequest.  # noqa: E501

        The unique ID of the snapshot you want to restore.  # noqa: E501

        :return: The snapshot_id of this CreateRestoreRequest.  # noqa: E501
        :rtype: str
        """
        return self._snapshot_id

    @snapshot_id.setter
    def snapshot_id(self, snapshot_id):
        """Sets the snapshot_id of this CreateRestoreRequest.

        The unique ID of the snapshot you want to restore.  # noqa: E501

        :param snapshot_id: The snapshot_id of this CreateRestoreRequest.  # noqa: E501
        :type snapshot_id: str
        """
        if self.local_vars_configuration.client_side_validation and snapshot_id is None:  # noqa: E501
            raise ValueError("Invalid value for `snapshot_id`, must not be `None`")  # noqa: E501

        self._snapshot_id = snapshot_id
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRestoreRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRestoreRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IONOS DBaaS MongoDB REST API

    With IONOS Cloud Database as a Service, you have the ability to quickly set up and manage a MongoDB database. You can also delete clusters, manage backups and users via the API.  MongoDB is an open source, cross-platform, document-oriented database program. Classified as a NoSQL database program, it uses JSON-like documents with optional schemas.  The MongoDB API allows you to create additional database clusters or modify existing ones. Both tools, the Data Center Designer (DCD) and the API use the same concepts consistently and are well suited for smooth and intuitive use.   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from ionoscloud_dbaas_mongo.configuration import Configuration


class PatchClusterProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {

        'display_name': 'str',

        'maintenance_window': 'MaintenanceWindow',

        'instances': 'int',

        'connections': 'list[Connection]',

        'template_id': 'str',
    }

    attribute_map = {

        'display_name': 'displayName',

        'maintenance_window': 'maintenanceWindow',

        'instances': 'instances',

        'connections': 'connections',

        'template_id': 'templateID',
    }

    def __init__(self, display_name=None, maintenance_window=None, instances=None, connections=None, template_id=None, local_vars_configuration=None):  # noqa: E501
        """PatchClusterProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._maintenance_window = None
        self._instances = None
        self._connections = None
        self._template_id = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        if maintenance_window is not None:
            self.maintenance_window = maintenance_window
        if instances is not None:
            self.instances = instances
        if connections is not None:
            self.connections = connections
        if template_id is not None:
            self.template_id = template_id


    @property
    def display_name(self):
        """Gets the display_name of this PatchClusterProperties.  # noqa: E501

        The name of your cluster.  # noqa: E501

        :return: The display_name of this PatchClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this PatchClusterProperties.

        The name of your cluster.  # noqa: E501

        :param display_name: The display_name of this PatchClusterProperties.  # noqa: E501
        :type display_name: str
        """

        self._display_name = display_name

    @property
    def maintenance_window(self):
        """Gets the maintenance_window of this PatchClusterProperties.  # noqa: E501


        :return: The maintenance_window of this PatchClusterProperties.  # noqa: E501
        :rtype: MaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """Sets the maintenance_window of this PatchClusterProperties.


        :param maintenance_window: The maintenance_window of this PatchClusterProperties.  # noqa: E501
        :type maintenance_window: MaintenanceWindow
        """

        self._maintenance_window = maintenance_window

    @property
    def instances(self):
        """Gets the instances of this PatchClusterProperties.  # noqa: E501

        The total number of instances in the cluster (one primary and n-1 secondaries).   # noqa: E501

        :return: The instances of this PatchClusterProperties.  # noqa: E501
        :rtype: int
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        """Sets the instances of this PatchClusterProperties.

        The total number of instances in the cluster (one primary and n-1 secondaries).   # noqa: E501

        :param instances: The instances of this PatchClusterProperties.  # noqa: E501
        :type instances: int
        """

        self._instances = instances

    @property
    def connections(self):
        """Gets the connections of this PatchClusterProperties.  # noqa: E501


        :return: The connections of this PatchClusterProperties.  # noqa: E501
        :rtype: list[Connection]
        """
        return self._connections

    @connections.setter
    def connections(self, connections):
        """Sets the connections of this PatchClusterProperties.


        :param connections: The connections of this PatchClusterProperties.  # noqa: E501
        :type connections: list[Connection]
        """
        if (self.local_vars_configuration.client_side_validation and
                connections is not None and len(connections) > 1):
            raise ValueError("Invalid value for `connections`, number of items must be less than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connections is not None and len(connections) < 0):
            raise ValueError("Invalid value for `connections`, number of items must be greater than or equal to `0`")  # noqa: E501

        self._connections = connections

    @property
    def template_id(self):
        """Gets the template_id of this PatchClusterProperties.  # noqa: E501

        The unique ID of the template, which specifies the number of cores, storage size, and memory. You cannot downgrade to a smaller template or minor edition (e.g. from business to playground). To get a list of all templates to confirm the changes use the /templates endpoint.   # noqa: E501

        :return: The template_id of this PatchClusterProperties.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this PatchClusterProperties.

        The unique ID of the template, which specifies the number of cores, storage size, and memory. You cannot downgrade to a smaller template or minor edition (e.g. from business to playground). To get a list of all templates to confirm the changes use the /templates endpoint.   # noqa: E501

        :param template_id: The template_id of this PatchClusterProperties.  # noqa: E501
        :type template_id: str
        """

        self._template_id = template_id
    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchClusterProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PatchClusterProperties):
            return True

        return self.to_dict() != other.to_dict()
